@@ -1,13 +1,13 @@
 # file MASS/corresp.q
-# copyright (C) 1994-2003 W. N. Venables and B. D. Ripley
+# copyright (C) 1994-2004 W. N. Venables and B. D. Ripley
 #
 corresp <- function(x, ...) UseMethod("corresp")
 
 corresp.xtabs <- function(x, ...)
 {
   if((m <- length(dim(x))) > 2)
-    stop(paste("Frequency table is", m, "dimensional"))
-  corresp.matrix(x)
+    stop(sprintf(gettext("frequency table is %d-dimensional"), m), domain = NA)
+  corresp.matrix(x, ...)
 }
 
 corresp.data.frame <- function(x, ...)
@@ -23,7 +23,7 @@ corresp.formula <- function(formula, data = parent.frame(), ...)
 {
     rhs <- formula[[length(formula)]]
     if(length(rhs[[2]]) > 1 || length(rhs[[3]]) > 1)
-        stop("higher way table requested.  Only 2 way allowed")
+        stop("higher-way table requested.  Only 2-way allowed")
     tab <- table(eval(rhs[[2]], data), eval(rhs[[3]], data))
     names(dimnames(tab)) <- as.character(c(rhs[[2]], rhs[[3]]))
     corresp.matrix(tab, ...)
